C---------------------------------------------------------------------
      SUBROUTINE CXBD1(IA,DRX,NRAMAX,IPUT,BENGY,VDEPTH,RPUT,FF)
C---------------------------------------------------------------------
C  INPUT
C    IA=1:Calculate the potential depth for the given binding energy
C      =2 Calculate the binding energy for the given potential depth
C    DRX   : Mesh size of r
C    NRAMAX: Number of mesh points
C    IPUT  : Orbit specification data (l,2s,2j,n)
C    RPUT  : masses, potential and Perey factor parameters
C    BENGY : Binding energy(complex)  if IA=1
C    VDEPTH: Potential depth(complex) if IA=2
C OUTPUT
C    BENGY : Binding energy(complex)  if IA=2
C    VDEPTH: Potential depth(complex) if IA=1
C    FF    : Bound state wave function   
C---------------------------------------------------------------------
      IMPLICIT NONE
C INPUTS:
      INTEGER IA,NRAMAX,IPUT(1:4)
      INTEGER NR2,LMOM,LMOM1,LMOM2,IS2,J2,NOD
      REAL    FLMOM1,FL1,FLMOM,FNOD
      REAL    DRX,RPUT(1:18)
      REAL    DRD,WSMAS,WMASS,WR0,WA0,WV0,WS0,WRV,WAV,WRI,WAI
      REAL    WLS,WRSO,WASO,WRC,WZZ,WREFF,WAEFF,BDIF
      COMPLEX BENGY,VDEPTH
C OUTPUTS:
      INTEGER ICOUN1,ICOUN2,ICOUN3,KCHECK
      INTEGER I
      REAL    SPWD
      COMPLEX ENGY
      COMPLEX WI0,FF(402)
      PARAMETER(WI0=(0.0,1.0))
C
      REAL MURATIO(1:402)
C
      REAL    EPS7,TEST,EPION
      PARAMETER( EPS7=1.E-4,TEST=21.0,EPION=0.7073195)
      REAL    RADI,RWV,RWI,RSO,RADZ,REFF,WR,RCO
      REAL    EX,EXV,EXI,EXSO,EXEFF
      REAL    WFCR(402),WFIVS(402),WFSR(402),WFC(402)
      COMPLEX FFR(402,2)
C
      INTEGER KOREC,NITER,INCR
      INTEGER IS2MN,IS2MX
      REAL    DRZ,FJS,FIS,FLNS
C
      REAL    FMU,WKA,WKPL,WKMI,WROZ
      REAL    WETA,WDRO,DRO56,DRO12
      COMPLEX WKC
C
      INTEGER K,MATCH
      REAL    T1
      COMPLEX WLOCAL(402),EPOT(402),WVC
C
      INTEGER IP2,IP
      REAL    WRO
      COMPLEX FAC1,FAC2,FAC3
C
      INTEGER NODES,NN,JRO,ITEN
      REAL    FNN,VCOR,DIFNCE
      COMPLEX ROEND,ROEND1,EXEND,EXEND1
      COMPLEX DFFR1,DFFR2,RATIO,TLOGD1,TLOGD2
      REAL    AST(20),TT1,TT2
      COMPLEX FRT1,FRT2,TRHOA
C
      COMPLEX FNUM,SUM,SUM1,SUM2,SUM3,DENOM,RAM1,RAMDA
C
      REAL    R,ALPHA
      COMPLEX ZNORM
C
C CONSTANTS
      real*8 hc/197.326968d0/
      real*8 CPI/3.141592654d0/
      real*8 AMU/931.494043d0/
      parameter(alpha=1.0d0/137.036d0)
C
      ICOUN1=0
      ICOUN2=0
      ICOUN3=0
      KCHECK=0
C
      IF(IA.EQ.1) THEN
        VDEPTH=(0.0,0.0)
      ELSE IF(IA.EQ.2) THEN
        BENGY=(0.0,0.0)
      END IF
      NR2=NRAMAX+2
      LMOM=IPUT(1)
      LMOM1=LMOM+1
      LMOM2=LMOM1+1
      FLMOM1=REAL(LMOM1)
      FL1=REAL(LMOM*LMOM1)
      FLMOM=REAL(LMOM)
      IS2=IPUT(2)
      J2=IPUT(3)
      NOD=IPUT(4)
      FNOD=NOD
      DRD=DRX
      WSMAS=RPUT(1)
      WMASS=RPUT(2)
      WR0=RPUT(3)
      WA0=RPUT(4)
      WV0=RPUT(5)
      WS0=RPUT(6)
      WRV=RPUT(7)
      WAV=RPUT(8)
      WRI=RPUT(9)
      WAI=RPUT(10)
      WLS=RPUT(11)
      WRSO=RPUT(12)
      WASO=RPUT(13)
      WZZ=RPUT(14)
      WREFF=RPUT(15)
      WAEFF=RPUT(16)
      BDIF=RPUT(17)
      WRC=RPUT(18)
C
      DO 6001 I=1,NR2
        FF(I)=(0.0,0.0)
 6001 CONTINUE
C
      RADI=WR0*WMASS**0.3333333
      RWV=WRV*WMASS**0.3333333
      RWI=WRI*WMASS**0.3333333
      RSO=WRSO*WMASS**0.3333333
      RCO=WRC*WMASS**0.3333333
      REFF=WREFF*WMASS**0.333333
      RADZ=RADI
C
      WR=DRD
      DO 5 I=1,NR2
        EX=EXP((WR-RADI)/WA0)
        EXV=EXP((WR-RWV)/WAV)
        EXI=EXP((WR-RWI)/WAI)
        EXSO=EXP((WR-RSO)/WASO)
        EXEFF=EXP((WR-REFF)/WAEFF)
        WFCR(I)=1.0/(1.0+EX)
        WFIVS(I)=WV0/(WV0+WS0)*1.0/(1.0+EXI)
     1          +WS0/(WV0+WS0)*4.0*EXV/((1.D0+EXV)*(1.D0+EXV))
 6400   WFSR(I)=EXSO/((1.0+EXSO)*(1.0+EXSO)*WR)
C
C COULOMB POTENTIAL
        IF(WR.LE.RCO) THEN
          WFC(I)=0.7199262*WZZ*(3.0-WR*WR/(RCO*RCO))/RCO
        ELSE IF(WR.GT.RCO) THEN
          WFC(I)=1.439852*WZZ/WR
        END IF
C EFFECTIVE MASS
        MURATIO(I)=1.0-BDIF/(1.0+EXEFF)
C
        WR=WR+DRD
 5    CONTINUE
C
C BEGINING OF SEARCH
C
      DRZ=0.0
      KOREC=0
      NITER=0
      INCR=0
      IF(IA.EQ.1) THEN
        GOTO 10
      ELSE IF(IA.EQ.2) THEN
        GOTO 20
      END IF
c
c Initial value of potential depth
c
   10 VDEPTH=BENGY+(CPI*(FNOD+0.5*FLMOM1))**2/(0.048228*
     1WSMAS*(RADI+DRZ)**2)+WFC(1)
      GO TO 30
c 
c Initial value of binding energy
c
   20 BENGY=VDEPTH-(CPI*(FNOD+0.5*FLMOM1))**2/(0.048228*
     1WSMAS*RADZ*RADZ)
C
      IF(REAL(BENGY).LE.EPS7) THEN
        GOTO 25
      ELSE IF(REAL(BENGY).GT.EPS7) THEN
        GOTO 30
      END IF
C
   25 IF(ABS(DRZ).LT.0.01) THEN
        DRZ=0.3
      END IF
C
      RADZ=RADZ+DRZ
      INCR=INCR+1
C
      IF(INCR.LE.10) THEN
        GOTO 20
      ELSE IF(INCR.GT.10) THEN
        GOTO 27
      END IF
C
   27 KCHECK=11
      WRITE(6,*) ' BENGY IS NOT LARGE ENOUGH IN CXBD.'
      GO TO 2000
c
c  Spin triangle relation check
c
   30 IS2MN=IABS(J2-2*LMOM)
      IS2MX=J2+2*LMOM
C
      IF(IS2.LT.IS2MN.OR.IS2.GT.IS2MX) THEN
        WRITE(6,*) ' IMPOSSIBLE COMB. OF J,L,S IN CXBD'
        GO TO 9999
      END IF
C
      FJS=0.5*REAL(J2)
      FIS=0.5*REAL(IS2)
      FLNS=FJS*(FJS+1.0)-FLMOM*(FLMOM+1.0)-FIS*(FIS+1.0)
C
      ENGY=-BENGY
   80 FMU=WSMAS*WMASS/(WSMAS+WMASS)*AMU
c
c Calculate complex momentum, eta(real)
c
      WKA=SQRT(2.0*FMU*ABS(ENGY)/HC**2)
      WKPL=SQRT((1.0+REAL(ENGY)/ABS(ENGY))/2.0)
      WKMI=SQRT((1.0-REAL(ENGY)/ABS(ENGY))/2.0)
      IF(REAL(ENGY).GE.0.0) THEN
        IF(AIMAG(ENGY).GE.0.0) THEN
          WKC=WKA*CMPLX(WKPL,WKMI)
        ELSE IF(AIMAG(ENGY).LT.0.0) THEN
          WKC=WKA*CMPLX(WKPL,-WKMI)
        END IF
      ELSE IF(REAL(ENGY).LT.0.0) THEN
        IF(AIMAG(ENGY).GE.0.0) THEN
          WKC=WKA*CMPLX(WKPL,WKMI)
        ELSE IF(AIMAG(ENGY).LT.0.0) THEN
          WKC=WKA*CMPLX(-WKPL,WKMI)
        END IF
      END IF
      WDRO=WKA*DRD
      WROZ=WKA*RADZ
      WETA=WZZ*ALPHA*FMU/HC/AIMAG(WKC)
C
      DRO12=1.0/12.0*WDRO**2
      DRO56=5.0/6.0*WDRO**2
C
 100  WVC=VDEPTH/ABS(ENGY)
C
      ICOUN1=ICOUN1+1
      IF(ICOUN1.GE.100) THEN
        WRITE(6,*) ' NOT CONVERGE IN CXBD'
        GOTO 9999
      END IF
C
      DO 101 I=1,NR2
      WLOCAL(I)=-REAL(VDEPTH)*WFCR(I)-WI0*AIMAG(VDEPTH)*WFIVS(I)
     #         -2.0*WLS/WASO*FLNS*WFSR(I)+WFC(I)
 101  CONTINUE
C
      WRO=WDRO
      DO 102 I=1,NR2
      EPOT(I)=MURATIO(I)*(ENGY/ABS(ENGY)-WLOCAL(I)/ABS(ENGY))
     #      -FL1/WRO**2
      WRO=WRO+WDRO
  102 CONTINUE
C
C*****( CALCULATE THE CLASSICAL TURNING POINT )*****
C
      DO 110 I=1,NRAMAX
        K=NRAMAX-I
        T1=REAL(EPOT(K))*REAL(EPOT(K+1))
        IF(T1.LT.0.0) GO TO 115
        IF(K.LE.5)    GO TO 115
  110 CONTINUE
  115 MATCH=K+1
C
      DO 120 I=1,NR2
        FFR(I,1)=(0.0,0.0)
 120  CONTINUE
C
      DO 130 I=1,NR2
        FFR(I,2)=(0.0,0.0)
 130  CONTINUE
C
      FFR(1,1)=WDRO**(LMOM+1)
      FAC2=2.0-DRO56*EPOT(1)
      FAC3=1.0+DRO12*EPOT(2)
      FFR(2,1)=FFR(1,1)*FAC2/FAC3
C
      DO 200 I=1,MATCH+3,1
      FAC1=1.0+DRO12*EPOT(I)
      FAC2=2.0-DRO56*EPOT(I+1)
      FAC3=1.0+DRO12*EPOT(I+2)
      FFR(I+2,1)=(FFR(I+1,1)*FAC2-FFR(I,1)*FAC1)/FAC3
      IF(ABS(FFR(I+2,1)).LT.TEST) THEN
      GOTO 200
      ELSE IF(ABS(FFR(I+2,1)).GE.TEST) THEN
      GOTO 185
      END IF
  185 IP2=I+2
      DO 190 IP=1,IP2
      FFR(IP,1)=FFR(IP,1)/TEST
  190 CONTINUE
  200 CONTINUE
C
C  NODE CHECK
C
      NODES=0
      DO 220 I=1,MATCH
      IF(REAL(FFR(I,1))*REAL(FFR(I+1,1)).LT.0.0) THEN
        NODES=NODES+2
      ELSE IF(REAL(FFR(I,1))*REAL(FFR(I+1,1)).EQ.0.0) THEN
        NODES=NODES+1
      ELSE IF(REAL(FFR(I,1))*REAL(FFR(I+1,1)).GT.0.0) THEN
        NODES=NODES
      END IF
  220 CONTINUE
      NN=NODES/2
      FNN=NN
      IF(NOD.LT.NN) THEN
        GOTO 225
      ELSE IF(NOD.EQ.NN) THEN
        GOTO 240
      ELSE IF(NOD.GT.NN) THEN
        GOTO 225
      END IF
  225 KOREC=KOREC+1
      IF(KOREC.LE.15) THEN
        GOTO 228
      ELSE
         KCHECK=10
         GO TO 2000
      END IF
C
  228 VCOR=(WROZ*WROZ+9.86959*(FNOD+0.5*FLMOM1)**2)/(WROZ*WROZ
     1+9.86959*(FNN+0.5*FLMOM1)**2)
C
      IF(IA.EQ.1) THEN
        GOTO 230
      ELSE IF(IA.EQ.2) THEN
        GOTO 235
      END IF
C
  230 VDEPTH=VCOR*VDEPTH
      GO TO 100
  235 ENGY=ENGY/VCOR
      GO TO 80
C
  240 DFFR1=((FFR(MATCH+3,1)-FFR(MATCH-3,1))/60.0+3.0*(FFR(MATCH-2,1)
     1-FFR(MATCH+2,1))/20.0+3.0*(FFR(MATCH+1,1)-FFR(MATCH-1,1))/4.0)
     2 /WDRO
      KOREC=0
C
C     Wave function of outer part
C
C     SET AST
      ast(1)=1.0
      tt1=1.0
      tt2=2.0
      do 320 i=1,15
         ast(i+1)=(flmom1-tt1-weta)*(flmom1+tt1-1.0+weta)*ast(i)/tt2
         tt1=tt1+1.0
         tt2=tt2+2.0
 320  continue
C
      JRO=NR2
  250 ROEND=WKC*DRD*REAL(JRO)
      ROEND1=WKC*DRD*REAL(JRO-1)
      EXEND =ROEND
      EXEND1=ROEND1
C
C        SET FRT
      frt1=1.0
      trhoa=-WI0*ROEND
      do 330 i=1,15
         frt1=frt1+ast(i+1)/trhoa
         trhoa=-trhoa*WI0*ROEND
 330  continue
      frt2=1.0
      trhoa=-WI0*ROEND1
      do 331 i=1,15
         frt2=frt2+ast(i+1)/trhoa
         trhoa=-trhoa*WI0*ROEND1
 331  continue
C
      IF((AIMAG(EXEND).GE.87.0).OR.
     &     (AIMAG(EXEND1).GE.87.0)) THEN
         JRO=JRO-1
         IF(JRO.LE.MATCH+3) THEN
            WRITE(6,*) ' ASYMPTOTIC FORM IS NOT FIXED IN CXBD '
            GOTO 9999
         END IF
         GOTO 250
      END IF
      FFR(JRO,2)=frt1*EXP(WI0*EXEND)
      FFR(JRO-1,2)=frt2*EXP(WI0*EXEND1)
C
      DO 260 I=JRO,MATCH-3,-1
      FAC1=1.0+DRO12*EPOT(I)
      FAC2=2.0-DRO56*EPOT(I-1)
      FAC3=1.0+DRO12*EPOT(I-2)
      FFR(I-2,2)=(FFR(I-1,2)*FAC2-FFR(I,2)*FAC1)/FAC3
      IF(ABS(FFR(I-2,2)).LT.TEST) THEN
        GOTO 260
      ELSE IF(ABS(FFR(I-2,2)).GE.TEST) THEN
        DO 280 ITEN=JRO,I-2,-1
          FFR(ITEN,2)=FFR(ITEN,2)/TEST
  280   CONTINUE
      END IF
  260 CONTINUE
C
      DFFR2=((FFR(MATCH+3,2)-FFR(MATCH-3,2))/60.0+3.0*(FFR(MATCH-2,2)
     1-FFR(MATCH+2,2))/20.0+3.0*(FFR(MATCH+1,2)
     2-FFR(MATCH-1,2))/4.0)/WDRO
      RATIO=FFR(MATCH,1)/FFR(MATCH,2)
      TLOGD1=DFFR1/FFR(MATCH,1)
      TLOGD2=DFFR2/FFR(MATCH,2)
      DIFNCE=ABS(TLOGD1-TLOGD2)
      IF(DIFNCE.LE.EPS7) THEN
        GOTO 510
      ELSE IF(DIFNCE.GT.EPS7) THEN
        GOTO 400
      END IF
C
  400 NITER=NITER+1
      IF(NITER.LE.500) THEN
        GOTO 410
      ELSE IF(NITER.GT.500) THEN
        GOTO 405
      END IF
  405 KCHECK=12
      GO TO 2000
C
  410 FNUM=CONJG(FFR(MATCH,2))*DFFR2*RATIO*CONJG(RATIO)
     &    -CONJG(FFR(MATCH,1))*DFFR1
C
      SUM=0.0
C
      DO 480 I=1,NRAMAX,2
      IF(I.LE.1) THEN
        GOTO 420
      ELSE IF(I.GT.1) THEN
        GOTO 430
      END IF
  420 SUM1=0.0
      GO TO 445
  430 IF(I.LE.MATCH) THEN
        GOTO 440
      ELSE IF(I.GT.MATCH) THEN
        GOTO 450
      END IF
  440 SUM1=FFR(I-1,1)*CONJG(FFR(I-1,1))
  445 SUM2=FFR(I,  1)*CONJG(FFR(I,  1))
      SUM3=FFR(I+1,1)*CONJG(FFR(I+1,1))
      GO TO 455
  450 SUM1=FFR(I-1,2)*CONJG(FFR(I-1,2))*CONJG(RATIO)*RATIO
      SUM2=FFR(I,  2)*CONJG(FFR(I,  2))*CONJG(RATIO)*RATIO
      SUM3=FFR(I+1,2)*CONJG(FFR(I+1,2))*CONJG(RATIO)*RATIO
  455 IF(IA.EQ.1) THEN
        GOTO 460
      ELSE IF(IA.EQ.2) THEN
        GOTO 470
      END IF
  460 IF(I.LE.1) THEN
        GOTO 462
      ELSE IF(I.GT.1) THEN
        GOTO 465
      END IF
  462 SUM1=0.0
      GO TO 467
  465 SUM1=-SUM1*WFCR(I-1)*WVC
  467 SUM2=-SUM2*WFCR(I)*WVC
      SUM3=-SUM3*WFCR(I+1)*WVC
  470 SUM=SUM+SUM1+4.0*SUM2+SUM3
  480 CONTINUE
      DENOM=SUM*WDRO/3.0
      INCR=0
      RAM1=FNUM/DENOM
C
  485 IF(1.0+REAL(RAM1).LE.0.0) THEN
        GOTO 486
      ELSE IF(1.0+REAL(RAM1).GT.0.0) THEN
        GOTO 487
      END IF
  486 RAM1=0.5*RAM1
      INCR=INCR+1
      IF(INCR.LE.10) THEN
        GOTO 485
      ELSE IF(INCR.GT.10) THEN
        GOTO 4861
      END IF
 4861 KCHECK=13
      GOTO 2000
  487 RAMDA=1.0+RAM1
      IF(ABS(RAMDA).GT.1.2) RAMDA=CMPLX(1.2,0.0)
      IF(ABS(RAMDA).LT.0.8) RAMDA=CMPLX(0.8,0.0)
C
  488 IF(IA.EQ.1) THEN
        VDEPTH=VDEPTH*RAMDA
        GO TO 100
      ELSE IF(IA.EQ.2) THEN
        ENGY=ENGY*RAMDA
        GO TO 80
      END IF
C
  510 KCHECK=0
      DO 520 I=MATCH,NR2
        FFR(I,1)=RATIO*FFR(I,2)
  520 CONTINUE
C
      DO 530 I=1,NR2,1
        FFR(I,1)=SQRT(MURATIO(I))*FFR(I,1)
 530  CONTINUE
C
      SUM=0.D0
      DO 570 I=1,NRAMAX,2
      IF(I.LE.1) THEN
        GOTO 540
      ELSE IF(I.GT.1) THEN
        GOTO 550
      END IF
  540 SUM1=0.D0
      GO TO 560
  550 SUM1=FFR(I-1,1)*CONJG(FFR(I-1,1))
  560 SUM2=FFR(I,  1)*CONJG(FFR(I,  1))
      SUM3=FFR(I+1,1)*CONJG(FFR(I+1,1))
      SUM=SUM+SUM1+4.0*SUM2+SUM3
  570 CONTINUE
      SUM=SUM*DRD/3.0
      ZNORM=1.0/SQRT(SUM)
      R=DRD
      DO 600 I=1,NR2
      FF(I)=ZNORM*FFR(I,1)
      R=R+DRD
  600 CONTINUE
 8000 CONTINUE
      IF(IA.EQ.2) BENGY=-ENGY
      RETURN
C
 2000 WRITE (6,7500) KCHECK
 7500 FORMAT(/,' SUBROUTINE BOUND KCHECK=',I3)
 9999 STOP
      END
